// /src/stores/machine.store.ts

import { defineStore } from 'pinia';
import { ref } from 'vue';
import type { Machine } from '@/types/Machine';
import * as machineService from '@/services/machine';

export const useMachineStore = defineStore('machine', () => {
  const machines = ref<Machine[]>([]);
  const loading = ref<boolean>(false);
  const error = ref<string | null>(null);

  // ดึงรายการ Machine ทั้งหมดจาก backend
  async function fetchMachines() {
    loading.value = true;
    error.value = null;
    try {
      machines.value = await machineService.listMachines();
    } catch (e: any) {
      error.value = e.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  // ดึงข้อมูล Machine รายการเดียวโดยใช้ MachineID
  async function fetchMachine(id: number): Promise<Machine | null> {
    loading.value = true;
    error.value = null;
    try {
      return await machineService.getMachine(id);
    } catch (e: any) {
      error.value = e.message || 'Unknown Error';
      return null;
    } finally {
      loading.value = false;
    }
  }

  // สร้าง Machine ใหม่แล้วเพิ่มเข้า state
  async function addMachine(payload: Partial<Machine>) {
    loading.value = true;
    error.value = null;
    try {
      const newMachine = await machineService.createMachine(payload);
      machines.value.push(newMachine);
    } catch (e: any) {
      error.value = e.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  // อัปเดต Machine ที่มีอยู่ใน state
  async function editMachine(id: number, payload: Partial<Machine>) {
    loading.value = true;
    error.value = null;
    try {
      const updatedMachine = await machineService.updateMachine(id, payload);
      const index = machines.value.findIndex(m => m.MachineID === id);
      if (index !== -1) {
        machines.value[index] = updatedMachine;
      }
    } catch (e: any) {
      error.value = e.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  // ลบ Machine จาก backend และอัปเดต state
  async function removeMachine(id: number) {
    loading.value = true;
    error.value = null;
    try {
      await machineService.deleteMachine(id);
      machines.value = machines.value.filter(m => m.MachineID !== id);
    } catch (e: any) {
      error.value = e.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  return {
    machines,
    loading,
    error,
    fetchMachines,
    fetchMachine,
    addMachine,
    editMachine,
    removeMachine,
  };
});
