// src/stores/material.store.ts

import { defineStore } from 'pinia';
import { ref } from 'vue';
import type { Material } from '@/types/Material';
import * as materialService from '@/services/material';

export const useMaterialStore = defineStore('material', () => {
  const materials = ref<Material[]>([]);
  const loading = ref<boolean>(false);
  const error = ref<string | null>(null);

  // ดึงรายการ Material ทั้งหมดจาก backend
  async function fetchMaterials() {
    loading.value = true;
    error.value = null;
    try {
      materials.value = await materialService.listMaterials();
    } catch (err: any) {
      error.value = err.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  // ดึงข้อมูล Material รายการเดียวโดยใช้ MaterialID
  async function fetchMaterial(id: number): Promise<Material | null> {
    loading.value = true;
    error.value = null;
    try {
      return await materialService.getMaterial(id);
    } catch (err: any) {
      error.value = err.message || 'Unknown Error';
      return null;
    } finally {
      loading.value = false;
    }
  }

  // สร้าง Material ใหม่แล้วเพิ่มเข้า state
  async function addMaterial(payload: Partial<Material>) {
    loading.value = true;
    error.value = null;
    try {
      const newMaterial = await materialService.createMaterial(payload);
      materials.value.push(newMaterial);
    } catch (err: any) {
      error.value = err.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  // อัปเดต Material ที่มีอยู่ใน state
  async function editMaterial(id: number, payload: Partial<Material>) {
    loading.value = true;
    error.value = null;
    try {
      const updatedMaterial = await materialService.updateMaterial(id, payload);
      const index = materials.value.findIndex(m => m.MaterialID === id);
      if (index !== -1) {
        materials.value[index] = updatedMaterial;
      }
    } catch (err: any) {
      error.value = err.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  // ลบ Material จาก backend และอัปเดต state
  async function removeMaterial(id: number) {
    loading.value = true;
    error.value = null;
    try {
      await materialService.deleteMaterial(id);
      materials.value = materials.value.filter(m => m.MaterialID !== id);
    } catch (err: any) {
      error.value = err.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  return {
    materials,
    loading,
    error,
    fetchMaterials,
    fetchMaterial,
    addMaterial,
    editMaterial,
    removeMaterial,
  };
});
