import { defineStore } from 'pinia';
import { ref } from 'vue';
import type { Page } from '@/types/Page';
import * as pageService from '@/services/page';

export const usePageStore = defineStore('page', () => {
  const pages = ref<Page[]>([]);
  const loading = ref(false);
  const error = ref<string | null>(null);

  async function fetchPages() {
    loading.value = true;
    error.value = null;
    try {
      pages.value = await pageService.listPages();
    } catch (e: any) {
      error.value = e.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  async function fetchPage(pagenum: number): Promise<Page | null> {
    loading.value = true;
    error.value = null;
    try {
      return await pageService.getPage(pagenum);
    } catch (e: any) {
      error.value = e.message || 'Unknown Error';
      return null;
    } finally {
      loading.value = false;
    }
  }

  async function addPage() {
    loading.value = true;
    error.value = null;
    try {
      const newPage = await pageService.createPage();
      pages.value.push(newPage);
    } catch (e: any) {
      error.value = e.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  async function editPage(pagenum: number, payload: Partial<Page>) {
    loading.value = true;
    error.value = null;
    try {
      const updated = await pageService.updatePage(pagenum, payload);
      const index = pages.value.findIndex(p => p.pagenum === pagenum);
      if (index !== -1) pages.value[index] = updated;
    } catch (e: any) {
      error.value = e.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  async function removePage(pagenum: number) {
    loading.value = true;
    error.value = null;
    try {
      await pageService.deletePage(pagenum);
      pages.value = pages.value.filter(p => p.pagenum !== pagenum);
    } catch (e: any) {
      error.value = e.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  return {
    pages,
    loading,
    error,
    fetchPages,
    fetchPage,
    addPage,
    editPage,
    removePage,
  };
});
