import { defineStore } from 'pinia';
import { ref } from 'vue';
import type { ProductionTarget } from '@/types/ProductionTarget';
import * as productionTargetService from '@/services/productionTarget';

export const useProductionTargetStore = defineStore('productionTarget', () => {
  const productionTargets = ref<ProductionTarget[]>([]);
  const loading = ref(false);
  const error = ref<string | null>(null);

  async function fetchProductionTargets() {
    loading.value = true;
    error.value = null;
    try {
      productionTargets.value = await productionTargetService.listProductionTargets();
    } catch (e: any) {
      error.value = e.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  async function fetchProductionTarget(id: number): Promise<ProductionTarget | null> {
    loading.value = true;
    error.value = null;
    try {
      return await productionTargetService.getProductionTarget(id);
    } catch (e: any) {
      error.value = e.message || 'Unknown Error';
      return null;
    } finally {
      loading.value = false;
    }
  }

  async function addProductionTarget(payload: Partial<ProductionTarget>) {
    loading.value = true;
    error.value = null;
    try {
      const newTarget = await productionTargetService.createProductionTarget(payload);
      productionTargets.value.push(newTarget);
    } catch (e: any) {
      error.value = e.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  async function editProductionTarget(id: number, payload: Partial<ProductionTarget>) {
    loading.value = true;
    error.value = null;
    try {
      const updated = await productionTargetService.updateProductionTarget(id, payload);
      const index = productionTargets.value.findIndex(p => p.ProductionTargetID === id);
      if (index !== -1) {
        // ✅ อัปเดตทั้ง ActualProduced และ Status จาก response backend
        productionTargets.value[index] = {
          ...productionTargets.value[index],
          ...updated, // รวม ActualProduced, Status และ field อื่น ๆ ที่ backend ส่งกลับ
        };
      }
    } catch (e: any) {
      error.value = e.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }
  
  

  async function editTodayTarget(payload: { ProductionTargetID: number, ActualProduced: number }) {
    loading.value = true;
    error.value = null;
    try {
      await productionTargetService.editTodayTarget(payload);
    } catch (e: any) {
      error.value = e.message || 'Unknown Error';
      throw e; // เพื่อให้ caller เช่นหน้า UI จับ error ได้
    } finally {
      loading.value = false;
    }
  }
  

  async function removeProductionTarget(id: number) {
    loading.value = true;
    error.value = null;
    try {
      await productionTargetService.deleteProductionTarget(id);
      productionTargets.value = productionTargets.value.filter(p => p.ProductionTargetID !== id);
    } catch (e: any) {
      error.value = e.message || 'Unknown Error';
    } finally {
      loading.value = false;
    }
  }

  return {
    productionTargets,
    loading,
    error,
    fetchProductionTargets,
    fetchProductionTarget,
    addProductionTarget,
    editTodayTarget,
    editProductionTarget,
    removeProductionTarget,
  };
});
