import { defineStore } from 'pinia'
import { computed, ref, watch } from 'vue'
import type { StockConfig } from '@/types/StockConfig'
import * as stockConfigService from '@/services/stockConfig'
import type {
  CreateStockConfigDto,
  UpdateStockConfigDto,
  BatchUpdateManyStockConfigDto
} from '@/types/StockConfigDto'

export const useStockConfigStore = defineStore('stockConfig', () => {
  const stockConfigs = ref<StockConfig[]>([])
  const loading = ref(false)
  const error = ref<string | null>(null)
  const isProductionSpare = ref(false)

  async function fetchStockConfigs(pageId?: number) {
    loading.value = true
    error.value = null
    try {
      const result = await stockConfigService.listStockConfigs(pageId)
      console.log('📥 stockConfigService.listStockConfigs response:', result)
      stockConfigs.value = result
    } catch (e: any) {
      error.value = e.message || 'Unknown Error'
      console.error('❌ fetchStockConfigs error:', e)
    } finally {
      loading.value = false
    }
  }

  async function fetchStockConfig(id: number): Promise<StockConfig | null> {
    loading.value = true
    error.value = null
    try {
      return await stockConfigService.getStockConfig(id)
    } catch (e: any) {
      error.value = e.message || 'Unknown Error'
      return null
    } finally {
      loading.value = false
    }
  }

  async function addStockConfig(payload: CreateStockConfigDto) {
    loading.value = true
    error.value = null
    try {
      const res = await stockConfigService.createStockConfig(payload)
      stockConfigs.value.push(res.stockConfig)
    } catch (e: any) {
      error.value = e.message || 'Unknown Error'
    } finally {
      loading.value = false
    }
  }

  async function editStockConfig(id: number, payload: UpdateStockConfigDto) {
    loading.value = true
    error.value = null
    try {
      const updated = await stockConfigService.updateStockConfig(id, payload)
      const index = stockConfigs.value.findIndex((c) => c.StockConfigID === id)
      if (index !== -1) {
        stockConfigs.value[index] = updated
      }
    } catch (e: any) {
      error.value = e.message || 'Unknown Error'
    } finally {
      loading.value = false
    }
  }

  async function batchUpdateStockConfigs(payload: BatchUpdateManyStockConfigDto) {
    loading.value = true
    error.value = null
    try {
      await stockConfigService.updateManyStockConfigs(payload)
      await fetchStockConfigs() // รีโหลดทั้งหมดเพื่อความชัวร์
    } catch (e: any) {
      error.value = e.message || 'Unknown Error'
    } finally {
      loading.value = false
    }
  }

  async function removeStockConfig(id: number) {
    loading.value = true
    error.value = null
    try {
      await stockConfigService.deleteStockConfig(id)
      stockConfigs.value = stockConfigs.value.filter((c) => c.StockConfigID !== id)
    } catch (e: any) {
      error.value = e.message || 'Unknown Error'
    } finally {
      loading.value = false
    }
  }
  const productionSpareLabel = computed(() =>
    isProductionSpare.value ? 'ทำการผลิตเผื่อ' : 'ไม่ทำการผลิตเผื่อ'
  )
  return {
    stockConfigs,
    loading,
    error,
    isProductionSpare,
    productionSpareLabel,
    fetchStockConfigs,
    fetchStockConfig,
    addStockConfig,
    editStockConfig,
    batchUpdateStockConfigs,
    removeStockConfig
  }
})
